==> vlc-0.8.1337.tar.bz2: vlc-0.8.1337/modules/gui/skins2/commands/cmd_add_item.cpp <==
/*****************************************************************************
 * cmd_add_item.cpp
 *****************************************************************************
 * Copyright (C) 2003 VideoLAN
 * $Id: cmd_add_item.cpp 10101 2005-03-02 16:47:31Z robux4 $
 *
 * Authors: Cyril Deguet     <asmax@via.ecp.fr>
 *          Olivier Teulire <ipkiss@via.ecp.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

#include <vlc/vlc.h>
#include "cmd_add_item.hpp"


void CmdAddItem::execute()
{
    playlist_t *pPlaylist = getIntf()->p_sys->p_playlist;
    if( pPlaylist == NULL )
    {
        return;
    }

    if( m_playNow )
    {
        // Enqueue and play the item
        playlist_Add( pPlaylist, m_name.c_str(),m_name.c_str(),
                      PLAYLIST_APPEND | PLAYLIST_GO, PLAYLIST_END );
    }
    else
    {
        // Enqueue the item only
        playlist_Add( pPlaylist, m_name.c_str(), m_name.c_str(),
                      PLAYLIST_APPEND, PLAYLIST_END );
    }
}

==> vlc-1.0.5.tar.bz2: vlc-1.0.5/modules/gui/skins2/commands/cmd_add_item.cpp <==
/*****************************************************************************
 * cmd_add_item.cpp
 *****************************************************************************
 * Copyright (C) 2003 the VideoLAN team
 * $Id: f90c188a1ed1d5f3bf7aac53667756dbcf161e89 $
 *
 * Authors: Cyril Deguet     <asmax@via.ecp.fr>
 *          Olivier Teulière <ipkiss@via.ecp.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include <vlc_common.h>
#include <vlc_playlist.h>
#include "cmd_add_item.hpp"

void CmdAddItem::execute()
{
    playlist_t *pPlaylist = getIntf()->p_sys->p_playlist;
    if( pPlaylist == NULL )
    {
        return;
    }

    if( m_playNow )
    {
        // Enqueue and play the item
        playlist_Add( pPlaylist, m_name.c_str(), NULL,
                      PLAYLIST_APPEND | PLAYLIST_GO, PLAYLIST_END, true,
                      false );
    }
    else
    {
        // Enqueue the item only
        playlist_Add( pPlaylist, m_name.c_str(), NULL,
                      PLAYLIST_APPEND, PLAYLIST_END, true, false );
    }
}
